Learn R Programming

tseriesTARMA (version 0.5-1)

TAR.test.B: AR versus TAR bootstrap supLM test for nonlinearity

Description

Implements various bootstrap supremum Lagrange Multiplier tests for a AR specification versus a TAR specification.

Usage

TAR.test.B(
  x,
  B = 1000,
  pa = 0.25,
  pb = 0.75,
  ar.ord,
  d = 1,
  btype = c("iid", "wb.h", "wb.r", "wb.n"),
  ...
)

Value

A list of class htest with components:

statistic

The value of the supLM statistic.

parameter

A named vector: threshold is the value that maximises the Lagrange Multiplier values.

test.v

Vector of values of the LM statistic for each threshold given in thd.range.

thd.range

Range of values of the threshold.

fit

The null model: AR fit over x.

sigma2

Estimated innovation variance from the AR fit.

data.name

A character string giving the name of the data.

prop

Proportion of values of the series that fall in the lower regime.

p.value

The bootstrap p-value of the test.

method

A character string indicating the type of test performed.

Tb

The bootstrap null distribution.

Arguments

x

A univariate time series.

B

Integer. Number of bootstrap resamples. Defaults to 1000.

pa

Real number in [0,1]. Sets the lower limit for the threshold search to the 100*pa-th sample percentile. The default is 0.25

pb

Real number in [0,1]. Sets the upper limit for the threshold search to the 100*pb-th sample percentile. The default is 0.75

ar.ord

Order of the AR part.

d

Delay parameter. Defaults to 1.

btype

Bootstrap type, can be one of 'iid','wb.h','wb.r','wb.n', see Details.

...

Additional arguments to be passed to arima.

Author

Simone Giannerini, simone.giannerini@uniud.it

Greta Goracci, greta.goracci@unibz.it

Details

Implements the bootstrap version of TAR.test the supremum Lagrange Multiplier test to test an AR specification versus a TARMA specification. The option btype specifies the type of bootstrap as follows:

iid

Residual iid bootstrap. See Gia22tseriesTARMA, Gia23tseriesTARMA.

wb.h

Stochastic permutation of Han96tseriesTARMA.

wb.r

Residual wild bootstrap with Rademacher auxiliary distribution. See Gia22tseriesTARMA, Gia23tseriesTARMA.

wb.n

Residual wild bootstrap with Normal auxiliary distribution. See Gia22tseriesTARMA, Gia23tseriesTARMA.

References

  • Gia22tseriesTARMA

  • Gia23tseriesTARMA

  • Gor23tseriesTARMA

  • Gia21tseriesTARMA

  • Han96tseriesTARMA

See Also

TAR.test for the heteroskedastic robust asymptotic test. TARMAGARCH.test for the robust version of the test with respect to GARCH innovations. TARMA.sim to simulate from a TARMA process.

Examples

Run this code
## a TAR(1,1) where the threshold effect is on the AR parameters
set.seed(123)
x1 <- TARMA.sim(n=100, phi1=c(0.5,-0.5), phi2=c(0.0,0.8), theta1=0, theta2=0, d=1, thd=0.2)
TAR.test.B(x1, ar.ord=1, d=1)
TAR.test.B(x1, ar.ord=1, d=1, btype='wb.r')
TAR.test.B(x1, ar.ord=1, d=1, btype='wb.h')

## a AR(1)
x2 <- arima.sim(n=100, model=list(order = c(1,0,0),ar=0.5))
TAR.test.B(x2, ar.ord=1, d=1)
TAR.test.B(x2, ar.ord=1, d=1, btype='wb.r')
TAR.test.B(x2, ar.ord=1, d=1, btype='wb.h')

Run the code above in your browser using DataLab