Learn R Programming

tseriesTARMA (version 0.5-2)

print.TARMAtest: Methods for TARMA tests

Description

Methods for TARMA tests

Usage

# S3 method for TARMAtest
print(x, ...)

Value

No return value, called for side effects

Arguments

x

A TARMAtest object.

...

Further parameters passed to print.htest.

Author

Simone Giannerini, simone.giannerini@uniud.it

Greta Goracci, greta.goracci@unibz.it

Details

Print method for TARMAtest objects. Prints the results using the method for class htest and adds critical values extracted from ACValues for the test for threshold nonlinearity and supLMQur for the unit root test against the TARMA alternative. Note that the bootstrap version of the tests also print the bootstrap p-value.

See Also